### Name: cir-package
### Title: Nonparametric estimation of monotone functions via isotonic
###   regression and centered isotonic regression
### Aliases: cir-package 'Isotonic Regression and Centered Isotonic
###   Regression' cir
### Keywords: package nonparametric survival

### ** Examples

### In the 'stackloss' dataset, escape of ammonia through some plant's
### chimney appears driven mostly by plant operation rate with a clearly
### monotone dependence. Linearity is questionable, though, and there
### are monotonicity violations in the data.
### There are are 21 observations at 8 distinct rates, and the original dataset is not ordered.
### "pava" and "cir.pava" require unique and ordered x values.
### So this example also shows how to prepare such data for input to
### "pava" or "cir.pava" (not difficult):

data(stackloss)
attach(stackloss)

meanrate=sort(unique(Air.Flow))
meanloss=sapply(split(stack.loss,Air.Flow),mean)/10 ## according to stackloss documentation, this turns the data into percent loss
weights=sapply(split(stack.loss,Air.Flow),length) ### we don't want to lose the effect of multiple observations at certain points

### Raw data shows overall monotone pattern, linearity questionable, but
### perhaps not enough points for fancy smoothers 
plot(meanrate,meanloss,main="CIR Example (Stack Loss data)",xlab="Plant Operation Rate (Air Flow)",ylab="Mean Ammonia Loss Through Stack (percent)")

### PAVA gives a staircase solution in black
lines(meanrate,pava(meanloss,wt=weights))

### try CIR for a much more realistic curve in red
lines(meanrate,cir.pava(y=meanloss,x=meanrate,wt=weights),col=2)
 
### Compare with standard linear regression line in blue
abline(lsfit(meanrate,meanloss,wt=weights),col=4)

### This just to display what the "full=T" option provides:
cir.pava(y=meanloss,x=meanrate,wt=weights,full=TRUE)

######## yes-no table example #####
### Taken from Lacassie and Columb
### Anesth. Analg. 97, 1509-1513, 2003.

levo=cbind(c(0,2,2,4,2,1,0,1),c(3,3,5,3,2,1,1,0))

levo

### you should get this table:

###     [,1] [,2]
#[1,]    0    3
#[2,]    2    3
#[3,]    2    5
#[4,]    4    3
#[5,]    2    2
#[6,]    1    1
#[7,]    0    1
#[8,]    1    0

### Note that all doses except the lowest and highest are involved in
### some monotonicity violation (in terms of observed frequency of 'yes' responses)

pava(levo)

### Since the experiment's goal was to estimate the ED50 of the drug
### abbreviated here as 'levo', pava's solution is highly problematic as
### you can pick and choose your favorite ED50 from any of doses 4
### through 7!
###
### We call 'cir.pava' to our aid, meaning we need to specify x values
### for the doses:

levdoses=seq(0.25,0.425,0.025) ### values taken from the article

cir.pava(levo,x=levdoses)

### Play with 'wt.overwrite' to see how it affects the solutions

### With CIR, the ED50 will be unique (though hard to directly pinpoint from
### the default vector output of 'cir.pava')
### We can use 'cir.upndown' for direct estimation of ED50 and its confidence
### interval on the same data using CIR.

levo.cir.outcome=cir.upndown(yesno=levo,xseq=levdoses,target=0.5,full=TRUE)

### The authors' old-fashioned averaging estimator for ED50 yields
### 0.31 as the point estimate, and a probit regression (as reported in the article) 
### places it at 0.37

### The CIR point estimate (below) is around 0.345, almost exactly in the
### middle between these two

levo.cir.outcome$out

### The authors' 95% confidence interval estimate is amazingly optimistic
### at (0.29,0.34). CIR's estimate is more conservative
### because it indirectly accounts for the gross monotonicity violations in the data
### It is more in line with the probit-regression estimate of (0.30,0.45)

levo.cir.outcome$ci




